Structs
- Create
Params - Prepared parameters for workflow creation — used by both the CLI (which spawns zag directly) and the API (which returns data to the frontend).
Functions
- prepare_
create - Prepare the prompts and configuration for workflow creation without launching zag. Returns structured data that can be used by the CLI to spawn zag or by the API to return to the frontend.
- run_
create - Launch an interactive zag session for workflow creation.