prepare_create

Function prepare_create 

pub fn prepare_create(
    name: Option<&str>,
    output: Option<&str>,
    pattern: Option<&str>,
) -> Result<CreateParams, ZigError>
Prepare the prompts and configuration for workflow creation without launching zag. Returns structured data that can be used by the CLI to spawn zag or by the API to return to the frontend.