pub fn print_plan(
ctx: &DryRunContext<'_>,
tiers: &[Vec<&Step>],
format: DryRunFormat,
) -> Result<(), ZigError>Expand description
Build the plan and print it to stdout in the requested format.
pub fn print_plan(
ctx: &DryRunContext<'_>,
tiers: &[Vec<&Step>],
format: DryRunFormat,
) -> Result<(), ZigError>Build the plan and print it to stdout in the requested format.