Module manage

Module manage 

Structs

WorkflowInfo
Summary information about a discovered workflow file.

Functions

delete_workflow
Delete a workflow file.
get_workflow_detail
Return the parsed workflow for a given workflow name or path.
get_workflow_list
Return structured data about all discovered workflows.
list_workflows
List all .zug workflow files found in the current directory, ./workflows/, and the global ~/.zig/workflows/ directory.
show_workflow
Show detailed information about a workflow.