pub enum MemoryTarget {
GlobalShared,
GlobalWorkflow(String),
Cwd,
}Expand description
Where a memory command should target.
Variants
Implementations
Sourceimpl MemoryTarget
impl MemoryTarget
Sourcepub fn from_flags(
workflow: Option<&str>,
global: bool,
cwd: bool,
) -> Result<Self, ZigError>
pub fn from_flags( workflow: Option<&str>, global: bool, cwd: bool, ) -> Result<Self, ZigError>
Resolve from CLI flag combination. Same rules as ResourceTarget.
Sourcepub fn ensure_dir(&self) -> Result<PathBuf, ZigError>
pub fn ensure_dir(&self) -> Result<PathBuf, ZigError>
Resolve to an absolute directory path, creating it if it doesn’t exist.
Sourcepub fn existing_dir(&self) -> Option<PathBuf>
pub fn existing_dir(&self) -> Option<PathBuf>
Resolve to an absolute directory path without creating it.