Functions
- cwd_
memory_ dir - Walk up from the process’s current working directory looking for a
.zig/memorydirectory. Seecwd_memory_dir_from. - cwd_
memory_ dir_ from - Walk up from
startlooking for a.zig/memorydirectory. Stops at the containing git repository root, or returns the directory instartitself if it exists. - cwd_
resources_ dir - Walk up from the process’s current working directory looking for a
.zig/resourcesdirectory. Seecwd_resources_dir_from. - cwd_
resources_ dir_ from - Walk up from
startlooking for a.zig/resourcesdirectory. Stops at the containing git repository root (matchingfind_git_root’s discovery boundary), or returns the directory instartitself if it exists. - cwd_
workflows_ dir - Walk up from the process’s current working directory looking for a
.zig/workflowsdirectory. Seecwd_workflows_dir_from. - cwd_
workflows_ dir_ from - Walk up from
startlooking for a.zig/workflowsdirectory. Stops at the containing git repository root, or returns the directory instartitself if it exists. - ensure_
global_ examples_ dir - Ensure the global examples directory exists, creating it if necessary.
- ensure_
global_ memory_ dir - Ensure the global memory directory (or a child of it) exists.
- ensure_
global_ resources_ dir - Ensure the global resources directory (or a child of it) exists.
- ensure_
global_ workflows_ dir - Ensure the global workflows directory exists, creating it if necessary.
- ensure_
project_ sessions_ dir - Ensure the per-project sessions directory exists, creating it if needed.
- global_
base_ dir - Return the global zig base directory:
~/.zig/. - global_
examples_ dir - Return the global examples directory:
~/.zig/examples/. - global_
memory_ dir - Return the global memory directory:
~/.zig/memory/. - global_
memory_ for - Return the per-workflow global memory directory:
~/.zig/memory/<name>/. - global_
resources_ dir - Return the global resources directory:
~/.zig/resources/. ReturnsNoneif the HOME environment variable is not set. - global_
resources_ dir_ from - Return the global resources directory derived from a given home directory.
- global_
resources_ for - Return the per-workflow global resources directory:
~/.zig/resources/<name>/. - global_
sessions_ index_ path - Return the global cross-project session index:
~/.zig/sessions_index.json. - global_
shared_ memory_ dir - Return the shared global memory directory:
~/.zig/memory/_shared/. - global_
shared_ resources_ dir - Return the shared global resources directory:
~/.zig/resources/_shared/. - global_
workflows_ dir - Return the global workflows directory:
~/.zig/workflows/. ReturnsNoneif the HOME environment variable is not set. - global_
workflows_ dir_ from - Return the global workflows directory derived from a given home directory.
- project_
dir - Resolve the project directory for session storage.
- project_
index_ path - Return the per-project index file:
<project>/logs/index.json. - project_
logs_ dir - Return the per-project logs directory:
<project>/logs/. - project_
sessions_ dir - Return the per-project sessions directory:
<project>/logs/sessions/. - sanitize_
project_ path - Sanitize an absolute path into a directory name.