pub fn cwd_memory_dir_from(start: &Path) -> Option<PathBuf>
Walk up from start looking for a .zig/memory directory. Stops at the containing git repository root, or returns the directory in start itself if it exists.
start
.zig/memory