cwd_workflows_dir_from

Function cwd_workflows_dir_from 

pub fn cwd_workflows_dir_from(start: &Path) -> Option<PathBuf>
Walk up from start looking for a .zig/workflows directory. Stops at the containing git repository root, or returns the directory in start itself if it exists.