resolve

Function resolve 

pub fn resolve(opts: &ContinueOptions) -> Result<ResumeTarget, ZigError>
Resolve which zag session to resume based on opts.

Resolution order:

  1. opts.session (exact id or unique prefix) → match in project index.
  2. opts.workflow → most recent project entry for that workflow name.
  3. Neither → most recent project entry.

In all cases the chosen entry’s JSONL log is read and the last StepStarted event determines the zag session id to resume.