extract_zip

Function extract_zip 

pub fn extract_zip(archive_path: &Path, dest: &Path) -> Result<(), ZigError>
Extract a zip archive into a destination directory.

Used by both [parse_zip] (into a temp directory) and update::run_update (into a staging directory for in-place editing). Returns an error if any entry has an invalid path, is a symlink, or if the cumulative extracted size exceeds [MAX_ZIP_TOTAL_BYTES].