zig-core — workflow orchestration engine for AI coding agents.
This crate provides the core library for parsing, validating, and executing
.zwf workflow files (and zipped .zwfz bundles). It powers the zig CLI.
Modules
- config
- Global zig configuration loaded from
~/.zig/config.toml. - create
- docs
- dry_run
zig run --dry-run— preview what a workflow would do without invoking the agent.- error
- listen
zig listen— tail a zig session log file in real time.- man
- manage
- memory
- Memory scratch pad for workflows and steps.
- pack
- paths
- prompt
- resources
- Resource file advertisement.
- resources_
manage - Management commands for resource files: list / add / delete / show / where.
- run
- session
- Zig session log: a recorded execution of
zig run. - storage
- Workflow storage — structured, writable working data for a run.
- update
- workflow