run_create

Function run_create 

pub fn run_create(
    name: Option<&str>,
    output: Option<&str>,
    pattern: Option<&str>,
) -> Result<(), ZigError>
Launch an interactive zag session for workflow creation.

The agent is given full context about zag and the .zug format, and guides the user through designing their workflow.