MemoryTarget

Enum MemoryTarget 

pub enum MemoryTarget {
    GlobalShared,
    GlobalWorkflow(String),
    Cwd,
}
Where a memory command should target.

Variants



GlobalShared

~/.zig/memory/_shared/



GlobalWorkflow(String)

~/.zig/memory/<workflow>/



Cwd

<git-root>/.zig/memory/

Implementations

Source

impl MemoryTarget

pub fn from_flags( workflow: Option<&str>, global: bool, cwd: bool, ) -> Result<Self, ZigError>

Resolve from CLI flag combination. Same rules as ResourceTarget.

pub fn ensure_dir(&self) -> Result<PathBuf, ZigError>

Resolve to an absolute directory path, creating it if it doesn’t exist.

pub fn existing_dir(&self) -> Option<PathBuf>

Resolve to an absolute directory path without creating it.

pub fn label(&self) -> String

Short label for diagnostic messages.