pack

Function pack 

pub fn pack(dir_path: &str, output: Option<&str>) -> Result<PathBuf, ZigError>
Pack a workflow directory into a .zug zip archive.

The directory must contain exactly one workflow TOML file (.toml or .zug that contains a [workflow] section). All files in the directory are included in the archive. The resulting zip file can be used directly with zig run and zig validate.