Module paths

Module paths 

Functions

cwd_resources_dir
Walk up from the process’s current working directory looking for a .zig/resources directory. See cwd_resources_dir_from.
cwd_resources_dir_from
Walk up from start looking for a .zig/resources directory. Stops at the containing git repository root (matching find_git_root’s discovery boundary), or returns the directory in start itself if it exists.
ensure_global_resources_dir
Ensure the global resources directory (or a child of it) exists.
ensure_global_workflows_dir
Ensure the global workflows directory exists, creating it if necessary.
ensure_project_sessions_dir
Ensure the per-project sessions directory exists, creating it if needed.
global_base_dir
Return the global zig base directory: ~/.zig/.
global_resources_dir
Return the global resources directory: ~/.zig/resources/. Returns None if the HOME environment variable is not set.
global_resources_dir_from
Return the global resources directory derived from a given home directory.
global_resources_for
Return the per-workflow global resources directory: ~/.zig/resources/<name>/.
global_sessions_index_path
Return the global cross-project session index: ~/.zig/sessions_index.json.
global_shared_resources_dir
Return the shared global resources directory: ~/.zig/resources/_shared/.
global_workflows_dir
Return the global workflows directory: ~/.zig/workflows/. Returns None if the HOME environment variable is not set.
global_workflows_dir_from
Return the global workflows directory derived from a given home directory.
project_dir
Resolve the project directory for session storage.
project_index_path
Return the per-project index file: <project>/logs/index.json.
project_logs_dir
Return the per-project logs directory: <project>/logs/.
project_sessions_dir
Return the per-project sessions directory: <project>/logs/sessions/.
sanitize_project_path
Sanitize an absolute path into a directory name.