Module paths

Module paths 

Functions

ensure_global_workflows_dir
Ensure the global workflows directory exists, creating it if necessary.
ensure_project_sessions_dir
Ensure the per-project sessions directory exists, creating it if needed.
global_base_dir
Return the global zig base directory: ~/.zig/.
global_sessions_index_path
Return the global cross-project session index: ~/.zig/sessions_index.json.
global_workflows_dir
Return the global workflows directory: ~/.zig/workflows/. Returns None if the HOME environment variable is not set.
global_workflows_dir_from
Return the global workflows directory derived from a given home directory.
project_dir
Resolve the project directory for session storage.
project_index_path
Return the per-project index file: <project>/logs/index.json.
project_logs_dir
Return the per-project logs directory: <project>/logs/.
project_sessions_dir
Return the per-project sessions directory: <project>/logs/sessions/.
sanitize_project_path
Sanitize an absolute path into a directory name.