pub fn resolve(opts: &ContinueOptions) -> Result<ResumeTarget, ZigError>Expand description
Resolve which zag session to resume based on opts.
Resolution order:
opts.session(exact id or unique prefix) → match in project index.opts.workflow→ most recent project entry for that workflow name.- Neither → most recent project entry.
In all cases the chosen entry’s JSONL log is read and the last
StepStarted event determines the zag session id to resume.