Skip to main contentModule model
Source - Role
- A reusable role definition that can be referenced by steps.
- Step
- A single workflow step — one agent invocation.
- Variable
- A workflow variable — shared state between steps.
- Workflow
- A complete workflow definition parsed from a
.zwf file. - WorkflowMeta
- Workflow-level metadata.
- FailurePolicy
- What to do when a step fails.
- MemoryMode
- Memory injection mode parsed from the
memory field on workflows/steps. - ResourceSpec
- A resource entry — a knowledge file the agent is told about (not inlined)
via the system prompt, so it can choose to read it with its file tools.
- StepCommand
- Zag command type for a step. When set, changes which zag subcommand
is invoked instead of the default
zag run. - VarType
- Supported variable types.