Module model

Module model 

Structs

Role
A reusable role definition that can be referenced by steps.
Step
A single workflow step — one agent invocation.
Variable
A workflow variable — shared state between steps.
Workflow
A complete workflow definition parsed from a .zug file.
WorkflowMeta
Workflow-level metadata.

Enums

FailurePolicy
What to do when a step fails.
StepCommand
Zag command type for a step. When set, changes which zag subcommand is invoked instead of the default zag run.
VarType
Supported variable types.