pub fn parse_file(path: &Path) -> Result<Workflow, ZigError>Expand description
Parse a .zug workflow file from disk.
If the file is a zip archive, it is extracted to a temp directory and
the TOML workflow inside is parsed. The returned WorkflowSource must
be kept alive for the duration of execution — dropping it cleans up
any temp directory.